@@ -5,7 +5,7 @@ os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'
 import tensorflow as tf
 from tensorflow import keras
 from tensorflow.keras import layers, regularizers, initializers
-from keras.layers.normalization import BatchNormalization
+from tensorflow.keras.layers import BatchNormalization
 import tensorflow_docs as tfdocs
 import tensorflow_docs.modeling
 import time
@@ -21,6 +21,10 @@ from matplotlib.ticker import AutoMinorLocator, MaxNLocator
 tf.compat.v1.logging.set_verbosity(tf.compat.v1.logging.ERROR)
 os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'
 
+from numpy.random import seed
+seed(1)
+tf.random.set_seed(1)
+
 
 def vectorize_random(array):
     """Returns a column vector and randomply shuffles the elements"""
@@ -857,24 +861,30 @@ class GradientComputation:
         """
 
         matrix = np.diag(np.ones(self.dataset.n_params) * self.step)
+        if len(x.shape)==1:
+            evals = self.dataset.norm_x(evals, verbose=False)
+            y = self.dataset.ret_qoi(self.network.predict(evals))
 
-        evals = np.array([]).reshape(0, self.dataset.n_params)
-        for point in x:
-            evals = np.vstack((evals, point + matrix, point - matrix))
+            y1 = y[:self.dataset.n_params]
+            y2 = y[self.dataset.n_params:]
+            grads = (y1 - y2) / (2 * self.step)
 
-        evals = pd.DataFrame(evals, columns=self.dataset.x.columns)
-        evals = self.dataset.norm_x(evals, verbose=False)
+        else:
 
-        y = self.dataset.ret_qoi(self.network.predict(evals))
+            evals = np.array([]).reshape(0, self.dataset.n_params)
+            for point in x:
+                evals = np.vstack((evals, point + matrix, point - matrix))
 
-        grads = np.array([]).reshape(0, self.dataset.n_params)
-        for i in range(x.shape[0]):
-            sector = y[self.dataset.n_params * 2 * i:self.dataset.n_params * 2 * (i + 1)]
-            y1 = sector[:self.dataset.n_params]
-            y2 = sector[self.dataset.n_params:]
-            result = (y1 - y2) / (2 * self.step)
+            evals = pd.DataFrame(evals, columns=self.dataset.x.columns)
 
-            grads = np.vstack((grads, result))
+            grads = np.array([]).reshape(0, self.dataset.n_params)
+            for i in range(x.shape[0]):
+                sector = y[self.dataset.n_params * 2 * i:self.dataset.n_params * 2 * (i + 1)]
+                y1 = sector[:self.dataset.n_params]
+                y2 = sector[self.dataset.n_params:]
+                result = (y1 - y2) / (2 * self.step)
+
+                grads = np.vstack((grads, result))
 
         return grads
 
